@@ -41,6 +41,19 @@ class BaseConfig:
     else:
         AUTH_TOKEN = ""
 
+    BEAT_SCHEDULES = [
+        {"name": "Materialized Database Daily (2 Days)", "minute": 10, "hour": 8, 'day_of_week': [
+            0, 2, 4, 6], 'task': 'run_daily_periodic_materialzation'},
+        {"name": "Materialized Database Daily (2 Days) (Wednesdays)", "minute": 10, "hour": 8,
+         'day_of_week': 3, 'day_of_month': '8-14,22-31', 'task': 'run_daily_periodic_materialzation'},
+        {"name": "Materialized Database Weekly (7 Days)", "minute": 10, "hour": 8, 'day_of_week': [
+            1, 5], 'task': 'run_weekly_periodic_materialzation'},
+        {"name": "Long Term Support Materialized Database (30 days)", "minute": 10, "hour": 8,
+         'day_of_week': 3, 'day_of_month': '1-7,15-21', 'task': 'run_lts_periodic_materialzation'},
+        {"name": "Remove Expired Databases (Midnight)", "minute": 0,
+         "hour": 8, 'task': 'remove_expired_databases'},
+    ]
+
 
 class DevConfig(BaseConfig):
     ENV = "development"
